=======
Modules
=======

Koodous API
-----------

.. autoclass:: koodous.api.Koodous
   :members:


Feed API
--------

Apks feed
~~~~~~~~~

.. autoclass:: koodous.feed.ApksFeed
    :members:

Analysis feed
~~~~~~~~~

.. autoclass:: koodous.feed.AnalysesFeed
    :members:
